@@ -1,8 +1,8 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        xh_notbk.h
+// Name:        wx/xrc/xh_notbk.h
 // Purpose:     XML resource handler for wxNotebook
 // Author:      Vaclav Slavik
-// RCS-ID:      $Id: xh_notbk.h,v 1.5 2005/01/07 21:27:19 VS Exp $
+// RCS-ID:      $Id: xh_notbk.h 53135 2008-04-12 02:31:04Z VZ $
 // Copyright:   (c) 2000 Vaclav Slavik
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -10,19 +10,16 @@
 #ifndef _WX_XH_NOTBK_H_
 #define _WX_XH_NOTBK_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "xh_notbk.h"
-#endif
-
 #include "wx/xrc/xmlres.h"
 
-#if wxUSE_NOTEBOOK
+#if wxUSE_XRC && wxUSE_NOTEBOOK
 
-class WXDLLEXPORT wxNotebook;
+class WXDLLIMPEXP_FWD_CORE wxNotebook;
 
 class WXDLLIMPEXP_XRC wxNotebookXmlHandler : public wxXmlResourceHandler
 {
-DECLARE_DYNAMIC_CLASS(wxNotebookXmlHandler)
+    DECLARE_DYNAMIC_CLASS(wxNotebookXmlHandler)
+
 public:
     wxNotebookXmlHandler();
     virtual wxObject *DoCreateResource();
@@ -33,6 +30,6 @@ private:
     wxNotebook *m_notebook;
 };
 
-#endif
+#endif // wxUSE_XRC && wxUSE_NOTEBOOK
 
 #endif // _WX_XH_NOTBK_H_
